==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/GatewaySpecFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewaySpecFluent<A extends GatewaySpecFluent<A>> extends Fluent<A>{
  public A addToSelector(String key,String value);
  public A addToSelector(Map<String,String> map);
  public A removeFromSelector(String key);
  public A removeFromSelector(Map<String,String> map);
  public Map<String,String> getSelector();
  public <K,V>A withSelector(Map<String,String> selector);
  public Boolean hasSelector();
  public A addToServers(Integer index,Server item);
  public A setToServers(Integer index,Server item);
  public A addToServers(io.fabric8.istio.api.networking.v1beta1.Server... items);
  public A addAllToServers(Collection<Server> items);
  public A removeFromServers(io.fabric8.istio.api.networking.v1beta1.Server... items);
  public A removeAllFromServers(Collection<Server> items);
  public A removeMatchingFromServers(Predicate<ServerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Server> getServers();
  public List<Server> buildServers();
  public Server buildServer(Integer index);
  public Server buildFirstServer();
  public Server buildLastServer();
  public Server buildMatchingServer(Predicate<ServerBuilder> predicate);
  public Boolean hasMatchingServer(Predicate<ServerBuilder> predicate);
  public A withServers(List<Server> servers);
  public A withServers(io.fabric8.istio.api.networking.v1beta1.Server... servers);
  public Boolean hasServers();
  public GatewaySpecFluent.ServersNested<A> addNewServer();
  public GatewaySpecFluent.ServersNested<A> addNewServerLike(Server item);
  public GatewaySpecFluent.ServersNested<A> setNewServerLike(Integer index,Server item);
  public GatewaySpecFluent.ServersNested<A> editServer(Integer index);
  public GatewaySpecFluent.ServersNested<A> editFirstServer();
  public GatewaySpecFluent.ServersNested<A> editLastServer();
  public GatewaySpecFluent.ServersNested<A> editMatchingServer(Predicate<ServerBuilder> predicate);
  public interface ServersNested<N> extends Nested<N>,ServerFluent<GatewaySpecFluent.ServersNested<N>>{
    public N and();
    public N endServer();
    
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/GatewaySpecFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GatewaySpecFluent<A extends GatewaySpecFluent<A>> extends Fluent<A>{
  public A addToSelector(String key,String value);
  public A addToSelector(Map<String,String> map);
  public A removeFromSelector(String key);
  public A removeFromSelector(Map<String,String> map);
  public Map<String,String> getSelector();
  public <K,V>A withSelector(Map<String,String> selector);
  public Boolean hasSelector();
  public A addToServers(int index,Server item);
  public A setToServers(int index,Server item);
  public A addToServers(io.fabric8.istio.api.networking.v1beta1.Server... items);
  public A addAllToServers(Collection<Server> items);
  public A removeFromServers(io.fabric8.istio.api.networking.v1beta1.Server... items);
  public A removeAllFromServers(Collection<Server> items);
  public A removeMatchingFromServers(Predicate<ServerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildServers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Server> getServers();
  public List<Server> buildServers();
  public Server buildServer(int index);
  public Server buildFirstServer();
  public Server buildLastServer();
  public Server buildMatchingServer(Predicate<ServerBuilder> predicate);
  public Boolean hasMatchingServer(Predicate<ServerBuilder> predicate);
  public A withServers(List<Server> servers);
  public A withServers(io.fabric8.istio.api.networking.v1beta1.Server... servers);
  public Boolean hasServers();
  public GatewaySpecFluent.ServersNested<A> addNewServer();
  public GatewaySpecFluent.ServersNested<A> addNewServerLike(Server item);
  public GatewaySpecFluent.ServersNested<A> setNewServerLike(int index,Server item);
  public GatewaySpecFluent.ServersNested<A> editServer(int index);
  public GatewaySpecFluent.ServersNested<A> editFirstServer();
  public GatewaySpecFluent.ServersNested<A> editLastServer();
  public GatewaySpecFluent.ServersNested<A> editMatchingServer(Predicate<ServerBuilder> predicate);
  public interface ServersNested<N> extends Nested<N>,ServerFluent<GatewaySpecFluent.ServersNested<N>>{
    public N and();
    public N endServer();
    
  }
  
}
